import React from 'react';
import { scaleSqrt, max } from 'd3';
import { Map } from './Map';

export const BubbleMap = ({
  data,
  mapData,
  x = 0,
  y = 0,
  width,
  height,
  margin = {
    top: 32,
    right: 32,
    bottom: 24,
    left: 32,
  },
}) => {
  const innerWidth =
    width - margin.left - margin.right;
  const innerHeight =
    height - margin.top - margin.bottom;

  const maxRadius = 16;
  const sizeValue = (d) =>
    d['Total Dead and Missing'];
  const sizeScale = scaleSqrt()
    .domain([0, max(data, sizeValue)])
    .range([0, maxRadius]);

  return (
    <g
      transform={`translate(${margin.left},${margin.top})`}
    >
      <Map
        width={innerWidth}
        height={innerHeight}
        mapData={mapData}
        data={data}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
      />
    </g>
  );
};
