import {
  scaleLinear,
  scaleTime,
  min,
  max,
  extent,
  timeFormat,
  timeMonths,
  histogram as bin,
  sum,
} from 'd3';
import { Marks } from './Marks';
import { AxisLeft } from './AxisLeft';
import { AxisBottom } from './AxisBottom';

export const DateHistorgram = ({
  data,
  x = 0,
  y = 0,
  width,
  height,
  margin = {
    top: 0,
    right: 64,
    bottom: 3,
    left: 92,
  },
}) => {
  const innerWidth =
    width - margin.left - margin.right;
  const innerHeight =
    height - margin.top - margin.bottom;

  const xAxisLabel = 'Time';
  const xAxisLabelOffset = 36;
  const xValue = (d) => d['Reported Date'];
  const xAxisTickFormat = timeFormat('%Y-%m-%d');
  const tooltipFormat = timeFormat('%b %Y');

  const yAxisLabel = 'Total Dead and Missing';
  const yAxisLabelOffset = 48;
  const yValue = (d) =>
    d['Total Dead and Missing'];

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const [start, stop] = xScale.domain();
  const binnedData = bin()
    .value(xValue)
    .domain(xScale.domain())
    .thresholds(timeMonths(start, stop))(data)
    .map((array) => ({
      'Total Dead and Missing': sum(
        array,
        yValue
      ),
      x0: array.x0,
      x1: array.x1,
    }));

  const yScale = scaleLinear()
    .domain([0, max(binnedData, yValue)])
    .range([innerHeight, 0])
    .nice();

  return (
    <g
      transform={`translate(${
        x + margin.left
      },${y})`}
    >
      <AxisBottom
        height={innerHeight}
        xScale={xScale}
        tickFormat={xAxisTickFormat}
      />
      <text
        className="axis-label"
        x={innerWidth / 2}
        y={innerHeight + xAxisLabelOffset}
        textAnchor="middle"
      >
        {xAxisLabel}
      </text>
      <AxisLeft
        innerWidth={innerWidth}
        yScale={yScale}
      />
      <text
        className="axis-label"
        textAnchor="middle"
        transform={`translate(${-yAxisLabelOffset},${
          innerHeight / 2
        }) rotate(-90)`}
      >
        {yAxisLabel}
      </text>
      <Marks
        data={binnedData}
        xScale={xScale}
        yScale={yScale}
        xValue={xValue}
        yValue={yValue}
        tooltipFormat={tooltipFormat}
        height={innerHeight}
      />
    </g>
  );
};
